# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-17 18:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('demoapp', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='DemoModelField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('char', models.CharField(max_length=255)),
                ('integer', models.IntegerField()),
                ('logic', models.BooleanField()),
                ('null_logic', models.NullBooleanField()),
                ('date', models.DateField()),
                ('datetime', models.DateTimeField()),
                ('time', models.TimeField()),
                ('decimal', models.DecimalField(decimal_places=3, max_digits=10)),
                ('email', models.EmailField(max_length=254)),
                ('float', models.FloatField()),
                ('bigint', models.BigIntegerField()),
                ('generic_ip', models.GenericIPAddressField()),
                ('url', models.URLField()),
                ('text', models.TextField()),
                ('unique', models.CharField(max_length=255, unique=True)),
                ('nullable', models.CharField(max_length=255, null=True)),
                ('blank', models.CharField(blank=True, max_length=255, null=True)),
                ('not_editable', models.CharField(blank=True, editable=False, max_length=255, null=True)),
                ('choices', models.IntegerField(choices=[(1, b'Choice 1'), (2, b'Choice 2'), (3, b'Choice 3')])),
            ],
        ),
        migrations.CreateModel(
            name='DemoModel_IntersectionFieldListFilter',
            fields=[
            ],
            options={
                'proxy': True,
                'verbose_name': 'IntersectionFieldListFilter',
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_RelatedFieldCheckBoxFilter',
            fields=[
            ],
            options={
                'proxy': True,
                'verbose_name': 'RelatedFieldCheckBoxFilter',
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_RelatedFieldRadioFilter',
            fields=[
            ],
            options={
                'proxy': True,
                'verbose_name': 'RelatedFieldRadioFilter',
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_UnionFieldListFilter',
            fields=[
            ],
            options={
                'proxy': True,
                'verbose_name': 'UnionFieldListFilter',
            },
            bases=('demoapp.demomodel',),
        ),
    ]
