{% load i18n %}
<h3>{% blocktrans with title as filter_title %} By {{ filter_title }} {% endblocktrans %}</h3>
<div>
    {% for choice in choices %}
        <input type="radio"{% if choice.selected %} checked="checked"{% endif %}
               onchange="location.href=this.value"
               value="{{ choice.query_string|iriencode }}"><a href="#" onclick="">{{ choice.display }}</a> <br/>
    {% endfor %}
</div>
